==> apache-camel-3.0.1-src.zip: apache-camel-3.0.1/core/camel-core/src/test/java/org/apache/camel/component/file/FileConsumerTemplateTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import java.io.File;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.junit.Before;
import org.junit.Test;

public class FileConsumerTemplateTest extends ContextTestSupport {

    @Override
    @Before
    public void setUp() throws Exception {
        deleteDirectory("target/data/consumer");
        super.setUp();
    }

    @Test
    public void testFileConsumerTemplate() throws Exception {
        template.sendBodyAndHeader("file:target/data/consumer", "Hello World", Exchange.FILE_NAME, "hello.txt");
        // file should exist
        File file = new File("target/data/consumer/hello.txt");

        assertTrue("File should exist " + file, file.exists());

        String body = consumer.receiveBody("file:target/data/consumer?delete=true", 5000, String.class);
        assertEquals("Hello World", body);

        // file should be deleted
        assertFalse("File should be deleted " + file, file.exists());
    }

}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/core/camel-core/src/test/java/org/apache/camel/component/file/FileConsumerTemplateTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file;

import java.nio.file.Files;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

public class FileConsumerTemplateTest extends ContextTestSupport {

    final String filename = "hello.txt";

    @Test
    public void testFileConsumerTemplate() {
        template.sendBodyAndHeader(fileUri(), "Hello World", Exchange.FILE_NAME, filename);

        // file should exist
        assertTrue(Files.exists(testFile(filename)), "File should exist " + filename);

        String body = consumer.receiveBody(fileUri("?delete=true"), 5000, String.class);
        assertEquals("Hello World", body);

        // file should be deleted
        assertFalse(Files.exists(testFile(filename)), "File should be deleted " + filename);
    }

}
